@@ -19,8 +19,3 @@ class WindowAggregateClass(Protocol):
 
     def value(self) -> SqliteData: ...
     def finalize(self) -> SqliteData: ...
-
-
-class StopRunning:
-    def __init__(self, token: object):
-        self.token = token
